@@ -4,7 +4,7 @@ use strict;
 require Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw/to_singular is_plural/;
-our $VERSION = '0.18';
+our $VERSION = '0.19';
 
 # Irregular plurals.
 
@@ -30,6 +30,7 @@ my %irregular = (qw/
     fungi fungus
     geese goose
     genera genus
+    gentlemen gentleman
     indices index
     lice louse
     matrices matrix
@@ -174,6 +175,8 @@ this
 thus
 various
 yes
+nucleus
+synchronous
 /);
 
 my %not_plural;
@@ -262,10 +265,28 @@ my %ies;
 @ies{@ies} = (1) x @ies;
 
 # Words which end in -se, so that we want the singular to change from
-# -ses to -se.
+# -ses to -se. This also contains verbs like "deceases", so that they
+# don't trigger spell checker errors.
 
 my @ses = (qw/
+automates
+bases
+cases
+causes
+ceases
+closes
+cornflakes
+creases
+databases
+deceases
+flakes
 horses
+increases
+mates
+parses
+purposes
+races
+releases
 tenses
 /);
 
@@ -358,6 +379,7 @@ my %i_to_o;
 @i_to_o{@i_to_o} = (1) x @i_to_o;
 
 # -i to something else
+
 my %i_to_other = (
     improvisatori => 'improvisatore',
     rhinoceri => 'rhinoceros',
@@ -464,13 +486,13 @@ sub is_plural
     my $singular = to_singular ($word);
     my $is_plural;
     if ($singular ne $word) {
-	    $is_plural = 1;
+	$is_plural = 1;
     }
     elsif ($plural{$singular} && $plural{$singular} eq $singular) {
-	    $is_plural = 1;
+	$is_plural = 1;
     }
     else {
-	    $is_plural = 0;
+	$is_plural = 0;
     }
     return $is_plural;
 }
